@@ -1,10 +1,10 @@
-from .monkey import patch  # noqa: E402
-from .monkey import patch_all
+from ._monkey import patch  # noqa: E402
+from ._monkey import patch_all
+from .internal.utils.deprecation import deprecated  # noqa: E402
 from .pin import Pin  # noqa: E402
 from .settings import _config as config  # noqa: E402
 from .span import Span  # noqa: E402
 from .tracer import Tracer  # noqa: E402
-from .utils.deprecation import deprecated  # noqa: E402
 from .version import get_version
 
 
